@@ -5,7 +5,7 @@ import json
 import sys
 import os
 from sf_virtual_data.common.models import VTCommandLineArgsBase
-from common.api import virtual_trends_pb2_grpc
+from sf_virtual_data.common.api import virtual_trends_pb2_grpc
 from sf_virtual_data.common.api import virtual_trends_pb2
 from sf_virtual_data.common.api import common_models_pb2
 from sf_virtual_data.common import utils
